all.Vanms<-function(){
     cat("\n")
     note_for_Vanss_input()
     cat("\n")
     note_for_close_window()
     VanMSpar<-data.frame(subject=c(1,2),Gender=c(0),age=c(0),bw=c(0),Scr=c(0),D=c(0),tau=c(0),tin=c(0),ts=c(0),c=c(0))
     VanMSpar<-edit(VanMSpar)
##     VanMSpar<-ymscheck(VanMSpar)
     cat("\n")
     Van.ms(length(VanMSpar$subject),VanMSpar$c,VanMSpar$tau,VanMSpar$ts,VanMSpar$tin,VanMSpar$D,VanMSpar$bw,VanMSpar$Scr,VanMSpar$Gender,VanMSpar$age)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Vanss_output()
     show(samplesStats("*"))
     cat("\n")
     C<-infcpr(VanMSpar$D,VanMSpar$tin,VanMSpar$tau,VanMSpar$ts+VanMSpar$tin)  
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)  
     C<-infcpr(VanMSpar$D,VanMSpar$tin,VanMSpar$tau,VanMSpar$tau)/(exp(-(samplesStats("cl")/samplesStats("v"))*(VanMSpar$tau-(VanMSpar$tin+1))))
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cpss_pr (mg/L)")
     output2<-coutput
     show(coutput)
     C<-infcpr(VanMSpar$D,VanMSpar$tin,VanMSpar$tau,VanMSpar$tau)  
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output3<-coutput
     show(coutput)
     cat("\n") 
     cal.again()
}